#####################################
# Uncomment the 2 lines below if 
# 1) a new window doesn't open or 
# 2) matplotlib crashes
#####################################
import matplotlib
#matplotlib.use('Agg')
#####################################
import matplotlib.pyplot as plt

from classy import Class
import numpy as np

params1 = {
    'output': 'tCl,pCl,lCl',
    'lensing': 'yes',
    'h': 0.67,
    'omega_b': 0.018,
    'omega_cdm': 0.12,
    'format': 'camb'}

params2 = {
    'output': 'tCl,pCl,lCl',
    'lensing': 'yes',
    'h': 0.67,
    'omega_b': 0.022,
    'omega_cdm': 0.12,
    'format': 'camb'}
	
params3 = {
    'output': 'tCl,pCl,lCl',
    'lensing': 'yes',
    'h': 0.67,
    'omega_b': 0.026,
    'omega_cdm': 0.12,
    'format': 'camb'}

l = np.array(range(2,2501))
TCMB= 2.7255
units=pow(TCMB*1.e6,2)
factor = l*(l+1)/(2*np.pi)*units


print("Now running class for model 1...")
cosmo1 = Class()
cosmo1.set(params1)
cosmo1.compute()
cls1 = cosmo1.lensed_cl(2500)

print("Now running class for model 2...")
cosmo2 = Class()
cosmo2.set(params2)
cosmo2.compute()
cls2 = cosmo2.lensed_cl(2500)

print("Now running class for model 3...")
cosmo3 = Class()
cosmo3.set(params3)
cosmo3.compute()
cls3 = cosmo3.lensed_cl(2500)

# This makes the plot and saves it as a PDF
print('Now making the plot...')
fig=plt.figure()
#plt.semilogx(l,factor*cls1['tt'][2:], 'b', label=r"$\alpha/\alpha_0=0.95$")
plt.plot(l,factor*cls1['tt'][2:], 'b', label=r"$\Omega_b h^2=0.018$")
plt.plot(l,factor*cls2['tt'][2:], 'k', label=r"$\Omega_b h^2=0.020$")
plt.plot(l,factor*cls3['tt'][2:], 'r', label=r"$\Omega_b h^2=0.022$")
plt.legend(loc='best')
#plt.title(r'BAO plot')
plt.xlabel(r"$\ell$")
plt.ylabel(r"$\ell(\ell+1)/(2\pi)C_\ell^{TT}$")
plt.grid()
# On linux or if you have an X enviroment the following will open a window  
plt.show()
fig.savefig("./Cls_python_wrapper.pdf")

cosmo1.empty()
cosmo1.struct_cleanup()
cosmo2.empty()
cosmo2.struct_cleanup()
cosmo3.empty()
cosmo3.struct_cleanup()
print("Exiting...")
exit()